# KMeans

This module uses the KMeans algorithm to assign events to clusters in an unsupervized manner.

Name

  The operation name; determines the name of the new metadata

X Channel, Y Channel

  The channels to apply the mixture model to.

X Scale, Y Scale

  Re-scale the data in Channel before fitting.

Num Clusters

  How many clusters to assign the data to.

By

  A list of metadata attributes to aggregate the data before estimating the model. For example, if the experiment has two pieces of metadata, `Time` and `Dox`, setting By to `["Time", "Dox"]` will fit the model separately to each subset of the data with a unique combination of `Time` and `Dox`.